@@ -1,7 +1,7 @@
 // qmidinet.cpp
 //
 /****************************************************************************
-   Copyright (C) 2010-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2010-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -55,7 +55,6 @@ qmidinetApplication::qmidinetApplication ( int& argc, char **argv, bool bGUI )
 		m_pIcon = NULL;
 	}
 
-
 #ifdef CONFIG_ALSA_MIDI
 	QObject::connect(
 		&m_udpd, SIGNAL(received(const QByteArray&, int)),
@@ -182,7 +181,7 @@ void qmidinetApplication::message (
 		m_pIcon->message(sTitle, sText);
 	} else {
 		const QString sMessage = sTitle + ": " + sText.simplified();
-		qCritical(sMessage.toUtf8().constData());
+		qCritical("%s", sMessage.toUtf8().constData());
 	}
 }
 
@@ -211,16 +210,17 @@ void qmidinetApplication::shutdown (void)
 qmidinetSystemTrayIcon::qmidinetSystemTrayIcon ( qmidinetApplication *pApp )
 	: QSystemTrayIcon(pApp), m_pApp(pApp), m_iSending(0), m_iReceiving(0)
 {
-	m_menu.addAction(
-		QIcon(":/images/qmidinet.png"),
+//	m_menu.addAction(QIcon(":/images/qmidinet.png"), QMIDINET_TITLE);
+//	m_menu.addSeparator();
+	m_menu.addAction(QIcon(":/images/menuOptions.png"),
 		tr("Options..."), this, SLOT(options()));
-	m_menu.addAction(tr("Reset"), this, SLOT(reset()));
+	m_menu.addAction(QIcon(":/images/menuReset.png"),
+		tr("Reset"), this, SLOT(reset()));
 	m_menu.addSeparator();
 	m_menu.addAction(tr("About..."), this, SLOT(about()));
 	m_menu.addAction(tr("About Qt..."), m_pApp->app(), SLOT(aboutQt()));
 	m_menu.addSeparator();
-	m_menu.addAction(
-		QIcon(":/images/formReject.png"),
+	m_menu.addAction(QIcon(":/images/menuQuit.png"),
 		tr("Quit"), m_pApp->app(), SLOT(quit()));
 
 	QSystemTrayIcon::setContextMenu(&m_menu);
@@ -293,22 +293,28 @@ void qmidinetSystemTrayIcon::reset (void)
 // About dialog.
 void qmidinetSystemTrayIcon::about (void)
 {
+	QStringList list;
+#ifdef CONFIG_DEBUG
+	list << tr("Debugging option enabled.");
+#endif
+#ifndef CONFIG_ALSA_MIDI
+	list << tr("ALSA MIDI support disabled.");
+#endif
+#ifndef CONFIG_JACK_MIDI
+	list << tr("JACK MIDI support disabled.");
+#endif
+
 	// Stuff the about box text...
 	QString sText = "<p>\n";
 	sText += "<b>" QMIDINET_TITLE " - " + tr(QMIDINET_SUBTITLE) + "</b><br />\n";
 	sText += "<br />\n";
 	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
-	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
-#ifndef CONFIG_ALSA_MIDI
-	sText += "<small><font color=\"red\">";
-	sText += tr("ALSA MIDI support disabled.");
-	sText += "</font></small><br />";
-#endif
-#ifndef CONFIG_JACK_MIDI
-	sText += "<small><font color=\"red\">";
-	sText += tr("JACK MIDI support disabled.");
-	sText += "</font></small><br />";
-#endif
+//	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "</small><br />\n";
+	if (!list.isEmpty()) {
+		sText += "<small><font color=\"red\">";
+		sText += list.join("<br />\n");
+		sText += "</font></small><br />\n";
+	}
 	sText += "<br />\n";
 	sText += tr("Website") + ": <a href=\"" QMIDINET_WEBSITE "\">" QMIDINET_WEBSITE "</a><br />\n";
 	sText += "<br />\n";
@@ -412,3 +418,4 @@ int main ( int argc, char* argv[] )
 
 
 // end of qmidinet.cpp
+
